<!DOCTYPE html>
<html lang="{{ config.locale }}">
<head>
    <title>{{ page_title }} - {{ site_title }}</title>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="shortcut icon" href="/static/favicon.ico">
    <link rel="stylesheet" href="/static/css/bootstrap.min.css">
    <link rel="stylesheet" href="/static/css/style.css">
</head>
<body>

<!-- Header -->
{% include "partials/header.html" %}

<!-- Main -->
<div class="container-fluid">
    <div class="row">
        {% block sidebar %}
            {% if sidebar %}
                {% include "partials/sidebar.html" %}
            {% endif %}
        {% endblock %}
        <div class="col-sm-{% if sidebar %}9{% else %}12{% endif %}">
            {% block main %}{% endblock %}
        </div>
    </div>
</div>

<!-- Footer -->
{% include "partials/footer.html" %}

</body>
</html>
