
.header {
  color: #CCC;
  background: #2C323D;
}

.header .container-fluid {
  padding-top: 20px;
  padding-bottom: 20px;
}

.header a {
  color: #DDD;
}

.header a:hover {
  color: #FFF;
  text-decoration: none;
}

.header .logo {
  margin-left: 20px;
  font-size: 20px;
  line-height: 34px;
}

.header .search-form {
  margin-right: 20px;
}

.menu {
  padding: 0;
  margin: 40px 20px;
  list-style: none;
}

.menu .pages {
  padding: 0;
  margin: 0;
  list-style: none;
}

.menu li {
  line-height: 30px;
}

.menu .category-title {
  margin: 25px 0 10px 0;
  font-size: 12px;
  text-transform: uppercase;
}

.menu .category.active .category-title {
  font-weight: bold;
}

.menu a {
  display: inline-block;
  line-height: 20px;
  color: #888;
}

.menu a:hover {
  color: #444;
  text-decoration: none;
}

.menu .page.active a {
  font-weight: bold;
  color: #444;
}

.page-home .header .search-form {
  display: none;
}

.home-search {
  text-align: center;
}

.home-categories {
  margin: 0 10px;
}

.home-categories .panel-heading {
  margin: 0;
  font-size: 100%;
  font-weight: normal;
}

.home-categories .panel-heading,
.home-categories .panel .page {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.content {
  padding: 40px;
  margin: 40px 20px;
  color: #555;
  border: 1px solid #E9E9E9;
  -webkit-box-shadow: 0 1px 50px rgba(0,0,0,0.1);
  box-shadow: 0 1px 50px rgba(0,0,0,0.1);
}

.content .title {
  margin: 0 0 30px 0;
}

.content h1,
.content h2,
.content h3,
.content h4,
.content h5,
.content h6 {
  color: #222;
}

.content p,
.content ul,
.content ol,
.content pre,
.content blockquote,
.content table,
.content iframe {
  margin-bottom: 1em;
}

.content img {
  display: block;
  height: auto;
  max-width: 100%;
  padding: 4px;
  margin: 0 auto;
  background: #FFF;
  border: 1px solid #D6D6D6;
  border-radius: 4px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}

.content code {
  color: #555;
  background-color: #FFFDDC;
}

.content pre {
  background: #FFFDDC;
  border: 0;
}

.content pre code {
  color: #657B83;
}

.content .hljs {
  background: none;
}

.content .page-meta {
  margin-top: 50px;
  font-size: 85%;
  color: #999;
}

.content .page-meta a {
  color: #999;
  border-bottom: 1px dotted #999;
}

.content .page-meta a:hover {
  color: #428BCA;
  text-decoration: none;
}

.footer .copyright {
  margin: 0 20px 40px 0;
  font-size: 85%;
  color: #999;
}

.page-excerpt .search-query {
  background: #FFFDDC;
}

.error {
  padding: 0 20px;
}

@media only screen and (max-width: 767px) {

  .home-search .form-group {
    margin-bottom: 0;
  }

  #home-search {
    margin-bottom: 10px;
  }

}
