{% extends "base.html" %}
{% block main %}
    <section class="content search">
        <h3 class="title">{{ _('Search results for') }}: {{ search }}</h3>
        {% if results %}
            {% for page in results %}
                <div class="page">
                    <h2 class="page-title"><a href="{{ page.link }}">{{ page.meta.title }}</a></h2>
                    <div class="page-excerpt">{{ page.excerpt }}</div>
                </div>
            {% endfor %}
        {% else %}
            <p class="nothing-found">{{ _('Nothing found for') }} «{{ search }}»</p>
        {% endif %}
    </section>
{% endblock %}
