<header class="header">
    <div class="container-fluid">
        <div class="row">
            <div class="col-sm-6">
                <a href="{{ url_for('index') }}" class="logo">{{ site_title }}</a>
            </div>
            {% if search_enabled %}
                <div class="col-sm-6">
                    <form class="search-form form-inline pull-right"
                          action="{{ url_for('search') }}"
                    >
                        <div class="form-group">
                            <label class="sr-only" for="search">{{ _('Search') }}</label>
                            <input type="search" class="form-control" name="q" id="search"
                                   value="{{ search }}" placeholder="{{ _('Search') }}">
                        </div>
                    </form>
                </div>
            {% endif %}
        </div>
    </div>
</header>
