<aside class="col-sm-3 hidden-xs">
    <ul class="menu">
        {%- for item in sidebar.children recursive %}
            <li>
                {% if item.current %}
                    <strong><a href="{{ item.link }}">{{ item.title }}</a></strong>
                {% else %}
                    <a href="{{ item.link }}">{{ item.title }}</a>
                {% endif %}
                {% if item.children %}
                    <ul>
                        {{ loop(item.children) }}
                    </ul>
                {% endif %}
            </li>
        {%- endfor %}
    </ul>
</aside>
