{% extends "base.html" %}
{% block main %}
    {% if page.content %}
        <section class="content">
            {% if not page.meta.hide_title %}
                <header class="title">{{ page.meta.title }}</header>
            {% endif %}
            <article>{{ page.content | safe }}</article>
            {% if page.meta.date %}
                <div class="page-meta clearfix">
                    <div class="last-updated pull-right">
                        {{ _('Last modified') }} {{ page.meta.date }}
                    </div>
                </div>
            {% endif %}
        </section>
    {% endif %}
    {% if page.hierarchy and not page.meta.hide_hierarchy %}
        <section class="content">
            <ol>
                {% for p in page.hierarchy.children %}
                    <li><a href="{{ p.link }}">{{ p.title }}</a></li>
                {% endfor %}
            </ol>
        </section>
    {% endif %}
{% endblock %}

